${ title }

<%inherit file="../base/base.html" /> <%namespace file="../base/base.html" import="header, setup_margin_labels" /> <%block name="title_head"> <%block name="extra_meta"> ${ setup_margin_labels(title) }
${ header(complete_header, title, report.subtitle, notes) }

${ _("Order Number:") }: | ${ report.workorder.identifier }
% if report.workorder.sellable:
${ _("Equipment") }: | ${ report.workorder.sellable.description }
% endif
${ _("Description") }: | ${ report.workorder.description }
${ _("Client") }: | ${ report.workorder.client.person.name }
${ _("Phone") }: | ${ report.workorder.client.person.get_formatted_phone_number()} | ${ _("Cell Phone") }: | ${ report.workorder.client.person.get_formatted_mobile_number()}
${ _("Estimated cost") }: | ${ format_price(report.workorder.estimated_cost) if \ report.workorder.estimated_cost else '' } | ${ _("Estimated start") }: | ${ format_date(report.workorder.estimated_start) } | ${ _("Estimated finish") }: | ${ format_date(report.workorder.estimated_finish) }

% if report.workorder.sale and report.workorder.order_items.count() > 0: <%include file="workorder-items.html" /> % endif
${ _("Quote") }:

    ${ report.workorder.defect_detected or report.workorder.defect_reported }

${ _("Client signature") }
${ report.workorder.client.get_description() }
${ _("Responsible signature") }
% if report.workorder.quote_responsible: ${ report.workorder.quote_responsible.get_description() }
% endif